sequencetools.partition_sequence_by_ratio_of_weights
====================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_by_ratio_of_weights.partition_sequence_by_ratio_of_weights
